==> ruqola-2.5.2.tar.xz: ruqola-2.5.2/src/widgets/notificationhistory/autotests/notificationhistorydelegatetest.cpp <==
/*
   SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: LGPL-2.0-or-later
*/

#include "notificationhistorydelegatetest.h"
#include "notificationhistory/notificationhistorydelegate.h"

#include <QTest>
QTEST_MAIN(NotificationHistoryDelegateTest)

NotificationHistoryDelegateTest::NotificationHistoryDelegateTest(QObject *parent)
    : QObject{parent}
{
}

void NotificationHistoryDelegateTest::shouldCompareAccountInfo()
{
    {
        NotificationHistoryDelegate::RoomAccount info;
        info.accountName = QStringLiteral("bla");
        info.channelName = QStringLiteral("bli");

        NotificationHistoryDelegate::RoomAccount info2;
        info2.accountName = QStringLiteral("bla");
        info2.channelName = QStringLiteral("bli");
        QCOMPARE(info, info2);
    }

    {
        NotificationHistoryDelegate::RoomAccount info;
        info.accountName = QStringLiteral("zz");
        info.channelName = QStringLiteral("kk");

        NotificationHistoryDelegate::RoomAccount info2;
        info2.accountName = QStringLiteral("bla");
        info2.channelName = QStringLiteral("bli");
        QVERIFY(info != info2);
    }

    {
        NotificationHistoryDelegate::RoomAccount info;
        info.accountName = QStringLiteral("bla");
        info.channelName = QStringLiteral("kk");

        NotificationHistoryDelegate::RoomAccount info2;
        info2.accountName = QStringLiteral("bla");
        info2.channelName = QStringLiteral("bli");
        QVERIFY(info != info2);
    }
    {
        NotificationHistoryDelegate::RoomAccount info;
        info.accountName = QStringLiteral("ss");
        info.channelName = QStringLiteral("bli");

        NotificationHistoryDelegate::RoomAccount info2;
        info2.accountName = QStringLiteral("bla");
        info2.channelName = QStringLiteral("bli");
        QVERIFY(info != info2);
    }

    {
        NotificationHistoryDelegate::RoomAccount info;

        NotificationHistoryDelegate::RoomAccount info2;
        QCOMPARE(info, info2);
    }
}

#include "moc_notificationhistorydelegatetest.cpp"

==> ruqola-2.6.1.tar.xz: ruqola-2.6.1/src/widgets/notificationhistory/autotests/notificationhistorydelegatetest.cpp <==
/*
   SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: LGPL-2.0-or-later
*/

#include "notificationhistorydelegatetest.h"
using namespace Qt::Literals::StringLiterals;

#include "notificationhistory/notificationhistorydelegate.h"

#include <QTest>
QTEST_MAIN(NotificationHistoryDelegateTest)

NotificationHistoryDelegateTest::NotificationHistoryDelegateTest(QObject *parent)
    : QObject{parent}
{
}

void NotificationHistoryDelegateTest::shouldCompareAccountInfo()
{
    {
        NotificationHistoryDelegate::RoomAccount info;
        info.accountName = u"bla"_s;
        info.channelName = u"bli"_s;

        NotificationHistoryDelegate::RoomAccount info2;
        info2.accountName = u"bla"_s;
        info2.channelName = u"bli"_s;
        QCOMPARE(info, info2);
    }

    {
        NotificationHistoryDelegate::RoomAccount info;
        info.accountName = u"zz"_s;
        info.channelName = u"kk"_s;

        NotificationHistoryDelegate::RoomAccount info2;
        info2.accountName = u"bla"_s;
        info2.channelName = u"bli"_s;
        QVERIFY(info != info2);
    }

    {
        NotificationHistoryDelegate::RoomAccount info;
        info.accountName = u"bla"_s;
        info.channelName = u"kk"_s;

        NotificationHistoryDelegate::RoomAccount info2;
        info2.accountName = u"bla"_s;
        info2.channelName = u"bli"_s;
        QVERIFY(info != info2);
    }
    {
        NotificationHistoryDelegate::RoomAccount info;
        info.accountName = u"ss"_s;
        info.channelName = u"bli"_s;

        NotificationHistoryDelegate::RoomAccount info2;
        info2.accountName = u"bla"_s;
        info2.channelName = u"bli"_s;
        QVERIFY(info != info2);
    }

    {
        NotificationHistoryDelegate::RoomAccount info;

        NotificationHistoryDelegate::RoomAccount info2;
        QCOMPARE(info, info2);
    }
}

#include "moc_notificationhistorydelegatetest.cpp"
